==> discord-streaming-1.2.0.tgz: package/streaming.js <==
/*
	Streamers Highligh Module for DiscordJS
	Author: Flisher (andre@jmle.net)

    // Todo: Add arguments description here
*/

module.exports = function(bot, options) {
    var cron = require('node-cron');
 
    // Add check on startup
    bot.on("ready", () => {
		Streaming.Check(bot, options);
	});
    
    // Add a Cron job every minutes
    var jobStreamingCheck = new cron.schedule('* * * * *', function(){
        /* Runs every minutes */
        Streaming.Check(bot, options);
    });   
}

Streaming = new Array()

Streaming.Check = function (bot, options) {
	if (options && options.live) {
		// Single Server Config, will default to first guild found in the bot
		guild = bot.guilds.first();
		Streaming.StreamersLive(guild, options)
		Streaming.StreamersNotLive(guild, options)
	}
	else {
		// Multi-Servers Config
		for(var key in options) {
			// check that guild is loaded			
			guild = bot.guilds.get(key);
			if (guild) {
				Streaming.StreamersLive(guild, options[key])
				Streaming.StreamersNotLive(guild,  options[key])
			}
		
			else {
				console.log(`Streaming.Check - Bot isn't connected to Guild "${key}"`)
			}
		}
	}
}

Streaming.StreamersLive = function(guild, options) {
	// Check if the bot can manage Roles for this guild
	if (guild.me.hasPermission("MANAGE_ROLES")) {
		// Loop trough presence to find streamers (type 1)
		presences = guild.presences;
		if (presences) {
			presences.forEach(function(element, key){
				if (element.game) {
					if (typeof(element.game.type) != undefined) {
						if (element.game.type == 1) {
							// key = user id
							member = guild.members.get(key)
							// Check if the "live" Role exist
							if (guild.roles.find(val => val.name === options.live)) {
								// Check if the position of the "live" role is managable by the bot
								if (guild.me.highestRole.position >= guild.roles.find(val => val.name === options.live).position) {
									// Check if there is a Role required in the configuration
									bypass = false;
									if (typeof(options.required) === "undefined") {
										// If there is no required role, bypass
										bypass = true;
									}
									else {
										// Check if the required role exist and log an error message if missing
										if (!guild.roles.find(val => val.name === options.required)) 
										{
											console.log(`StreamersLive - REQUIRED Role "${options.live}" doesn't exist on Guild "${guild.name}" (${guild.id})`);
										}

									}
									if (bypass || (member.roles.find(val => val.name === options.required))) {
										// Check if the member doesn't already have the live role
										if (!(member.roles.find(val => val.name === options.live))) {
											member.addRole(guild.roles.find(val => val.name === options.live)).catch(console.error);
										}
									}								
								}
								else {
									console.log(`StreamersLive - LIVE Role "${options.live}" is higher than the bot highest permission on Guild "${guild.name}" (${guild.id})`);
								}
							}
							else {
								console.log(`StreamersLive - LIVE Role "${options.live}" doesn't exist on Guild "${guild.name}" (${guild.id})`);
							}
						}
					}
				}
			});
		}
	} 
	else {
		console.log(`StreamersLive - Bot doesn't have "MANAGE_ROLES" permission on Guild "${guild.name}" (${guild.id})`);
	}
}

Streaming.StreamersNotLive = function(guild, options) {
	// Check if the bot can manage Roles for this guild
	if (guild.me.hasPermission("MANAGE_ROLES")) {
		// Check if the live Role exist
		if (guild.roles.find(val => val.name === options.live)) {
			// Check if the position of the "live" role is managable by the bot
			if (guild.me.highestRole.position >= guild.roles.find(val => val.name === options.live).position) {
				// Loop les membres du Role Live pour ret
				streamers = guild.roles.find(val => val.name === options.live).members
				streamers.forEach(function(member, key){
					stillStreaming = 0;
					presence = member.guild.presences.get(key);
					if (presence) {
						if (presence.game) {
							if (typeof(presence.game.type) != undefined) {
								if (presence.game.type = 1) {
									stillStreaming = 1;
								}
							}
						}
						if (stillStreaming == 0)
						{
							member.removeRole(guild.roles.find(val => val.name === options.live)).catch(console.error);
						}
					}
				});
			}
			else {
				console.log(`StreamersNotLive - LIVE Role "${options.live}" is higher than the bot highest permission on Guild "${guild.name}" (${guild.id})`);
			}
		}
		else {
			console.log(`StreamersNotLive - LIVE Role "${options.live}" doesn't exist on Guild "${guild.name}" (${guild.id})`);
		}
	}
	else {
		console.log(`StreamersNotLive - Bot doesn't have "MANAGE_ROLES" permission on Guild "${guild.name}" (${guild.id})`);
	}
}

==> discord-streaming-1.3.1.tgz: package/streaming.js <==
/*
	Streamers Highligh Module for DiscordJS
	Author: Flisher (andre@jmle.net)

1.3.1 NoseJS Linting and fixed error message related to required role
1.2.0 Improved collection.find to the new format (remove deprecation warning in discord.js v11.4 and prepare for v12)
1.1.1 Bugfix on a crashing condition when presence can't be read properly
1.0.6 Improved README.md instructions  
1.0.5 Updating README.me code sample to properly load the module
1.0.4 Updating README.me code sample  
1.0.2 Removed a console.log debug message  
1.0.1 Fixed some typos  
1.0.0 Initial publish  

// Todo: Add arguments description here
*/

module.exports = function(bot, options) {
    var cron = require('node-cron');
 
    // Add check on startup
    bot.on("ready", () => {
		Streaming.Check(bot, options);
	});
    
    // Add a Cron job every minutes
    var jobStreamingCheck = new cron.schedule('* * * * *', function(){
        /* Runs every minutes */
        Streaming.Check(bot, options);
	});   
	
	
}

Streaming = new Array()

Streaming.Check = function (bot, options) {
	if (options && options.live) {
		// Single Server Config, will default to first guild found in the bot
		guild = bot.guilds.first();
		Streaming.StreamersLive(guild, options)
		Streaming.StreamersNotLive(guild, options)
	}
	else {
		// Multi-Servers Config
		for(var key in options) {
			// check that guild is loaded			
			guild = bot.guilds.get(key);
			if (guild) {
				Streaming.StreamersLive(guild, options[key])
				Streaming.StreamersNotLive(guild,  options[key])
			}
		
			else {
				console.log(`Streaming.Check - Bot isn't connected to Guild "${key}"`)
			}
		}
	}
}

Streaming.StreamersLive = function(guild, options) {
	// Check if the bot can manage Roles for this guild
	if (guild.me.hasPermission("MANAGE_ROLES")) {
		// Loop trough presence to find streamers (type 1)
		presences = guild.presences;
		if (presences) {
			presences.forEach(function(element, key){
				if (element.game) {
					if (typeof(element.game.type) != undefined) {
						if (element.game.type == 1) {
							// key = user id
							member = guild.members.get(key)
							// Check if the "live" Role exist
							if (guild.roles.find(val => val.name === options.live)) {
								// Check if the position of the "live" role is managable by the bot
								if (guild.me.highestRole.position >= guild.roles.find(val => val.name === options.live).position) {
									// Check if there is a Role required in the configuration
									bypass = false;
									if (typeof(options.required) === "undefined") {
										// If there is no required role, bypass
										bypass = true;
									}
									else {
										// Check if the required role exist and log an error message if missing
										if (!guild.roles.find(val => val.name === options.required)) 
										{
											console.log(`StreamersLive - REQUIRED Role "${options.required}" doesn't exist on Guild "${guild.name}" (${guild.id})`);
										}

									}
									if (bypass || (member.roles.find(val => val.name === options.required))) {
										// Check if the member doesn't already have the live role
										if (!(member.roles.find(val => val.name === options.live))) {
											member.addRole(guild.roles.find(val => val.name === options.live)).catch(console.error);
										}
									}								
								}
								else {
									console.log(`StreamersLive - LIVE Role "${options.required}" is higher than the bot highest permission on Guild "${guild.name}" (${guild.id})`);
								}
							}
							else {
								console.log(`StreamersLive - LIVE Role "${options.live}" doesn't exist on Guild "${guild.name}" (${guild.id})`);
							}
						}
					}
				}
			});
		}
	} 
	else {
		console.log(`StreamersLive - Bot doesn't have "MANAGE_ROLES" permission on Guild "${guild.name}" (${guild.id})`);
	}
}

Streaming.StreamersNotLive = function(guild, options) {
	// Check if the bot can manage Roles for this guild
	if (guild.me.hasPermission("MANAGE_ROLES")) {
		// Check if the live Role exist
		if (guild.roles.find(val => val.name === options.live)) {
			// Check if the position of the "live" role is managable by the bot
			if (guild.me.highestRole.position >= guild.roles.find(val => val.name === options.live).position) {
				// Loop les membres du Role Live pour ret
				streamers = guild.roles.find(val => val.name === options.live).members
				streamers.forEach(function(member, key){
					stillStreaming = 0;
					presence = member.guild.presences.get(key);
					if (presence) {
						if (presence.game) {
							if (typeof(presence.game.type) != undefined) {
								if (presence.game.type = 1) {
									stillStreaming = 1;
								}
							}
						}
						if (stillStreaming == 0)
						{
							member.removeRole(guild.roles.find(val => val.name === options.live)).catch(console.error);
						}
					}
				});
			}
			else {
				console.log(`StreamersNotLive - LIVE Role "${options.live}" is higher than the bot highest permission on Guild "${guild.name}" (${guild.id})`);
			}
		}
		else {
			console.log(`StreamersNotLive - LIVE Role "${options.live}" doesn't exist on Guild "${guild.name}" (${guild.id})`);
		}
	}
	else {
		console.log(`StreamersNotLive - Bot doesn't have "MANAGE_ROLES" permission on Guild "${guild.name}" (${guild.id})`);
	}
}
